# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/)


## [In Development] - Unreleased


## [0.0.1] - 2022-01-25

- First public release
- Skins included:
  - [Moono-Dark](https://ckeditor.com/cke4/addon/moono-dark)
  - [Prestige](https://ckeditor.com/cke4/addon/prestige)
